// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GCTEXT = GrapeCity.Documents.Text;
using GCDRAW = GrapeCity.Documents.Drawing;

namespace DsPdfWeb.Demos.Basics
{
    // 大規模な PDF ファイルを生成します。
    // このサンプルは StartEndDoc と同じですが、StartDoc/EndDoc メソッドを使用しません。
    // 消費メモリを増やすことになりますが、パフォーマンスが向上する可能性があります。
    public class LargeDocument2
    {
        public int CreatePDF(Stream stream)
        {
            // 生成するページ数を設定します。
            const int N = Common.Util.LargeDocumentIterations;
            var start = Common.Util.TimeNow();
            var doc = new GcPdfDocument();
            // テキストを保持/書式設定するための TextLayout を準備します。
            var tl = new TextLayout(72)
            {
                MaxWidth = doc.PageSize.Width,
                MaxHeight = doc.PageSize.Height,
                MarginAll = 72,
                FirstLineIndent = 36,
            };
            tl.DefaultFormat.FontName = "Yu Gothic";
            tl.DefaultFormat.FontSize = 12;
            // ドキュメントを生成します。
            for (int pageIdx = 0; pageIdx < N; ++pageIdx)
            {
                tl.Append(Common.Util.getString_ja(1, 0, 1));
                tl.PerformLayout(true);
                doc.NewPage().Graphics.DrawTextLayout(tl, PointF.Empty);
                tl.Clear();
            }
            // タイトルページを挿入します（StartDoc/EndDoc を使用している場合はできません）。
            tl.FirstLineIndent = 0;
            var fnt = GCTEXT.Font.FromFile(Path.Combine("Resources", "Fonts", "yumin.ttf"));
            var tf0 = new TextFormat() { Font = fnt, FontSize = 24, FontBold = true };
            tl.Append(string.Format("大規模なドキュメント\n{0} ページのテキストデータ\n\n", N), tf0);
            var tf1 = new TextFormat(tf0) { FontSize = 14, FontItalic = true };
            tl.Append(string.Format("生成日時 {0}、作成時間 {1:m\\m\\ s\\s\\ fff\\m\\s}", Common.Util.TimeNow(), Common.Util.TimeNow() - start), tf1);
            tl.TextAlignment = TextAlignment.Center;
            tl.PerformLayout(true);
            doc.Pages.Insert(0).Graphics.DrawTextLayout(tl, PointF.Empty);
            // PDF ドキュメントを保存します。
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
